@@ -256,10 +256,9 @@ class Insight_Definition:
 
         return self.components[position]["id"]
 
+    def edit_table(self, table_id, query="", columns=[], pivot_col=[], pivot_type="2"):
 
-    def edit_table(self, table_id, query="", columns=[]):
-
-        url = self.smart_insight_url + "/definitions/" + self.definition_id + "/tables/"+ table_id
+        url = self.smart_insight_url + "/definitions/" + self.definition_id + "/tables/" + table_id
 
         body = {
             "id": table_id,
@@ -269,9 +268,12 @@ class Insight_Definition:
             "dependsOn": ["q1"],
             "queryId": query,
             "columns": columns,
-            "maxResults":50,
-            "valid":True,
-            "queryComponent":False
+            "maxResults": 50,
+            "valid": True,
+            "queryComponent":False,
+            "pivot": len(pivot_col)!=0,
+            "pivotColumns": pivot_col,
+            "pivotType": pivot_type
         }
         r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
